@@ -1,14 +1,19 @@
 (** Functional lenses.
-  
-  Based on F# implementation in {{:https://github.com/fsharp/fsharpx}FSharpx}
-  (see {{:https://github.com/fsharp/fsharpx/blob/master/src/FSharpx.Core/Lens.fs}src/FSharpx.Core/Lens.fs} for the original implementation)
-  
-  @see <http://bugsquash.blogspot.com/2011/11/lenses-in-f.html> Lenses in F#
-  @see <http://stackoverflow.com/questions/8179485/updating-nested-immutable-data-structures> Stackoverflow question about Updating nested immutable data structures
-  @see <http://stackoverflow.com/questions/5767129/lenses-fclabels-data-accessor-which-library-for-structure-access-and-mutatio> Haskell libraries for structure access and mutation
-  @see <http://www.youtube.com/watch?v=efv0SQNde5Q> Functional lenses for Scala by Edward Kmett on YouTube
-  @see <http://patternsinfp.wordpress.com/2011/01/31/lenses-are-the-coalgebras-for-the-costate-comonad/> Lenses are the coalgebras for the costate comonad by Jeremy Gibbons
-  *)
+
+    Based on F# implementation in {{:https://github.com/fsharp/fsharpx}FSharpx}
+    (see
+    {{:https://github.com/fsharp/fsharpx/blob/master/src/FSharpx.Core/Lens.fs}src/FSharpx.Core/Lens.fs}
+    for the original implementation)
+
+    @see <http://bugsquash.blogspot.com/2011/11/lenses-in-f.html> Lenses in F#
+    @see <http://stackoverflow.com/questions/8179485/updating-nested-immutable-data-structures>
+      Stackoverflow question about Updating nested immutable data structures
+    @see <http://stackoverflow.com/questions/5767129/lenses-fclabels-data-accessor-which-library-for-structure-access-and-mutatio>
+      Haskell libraries for structure access and mutation
+    @see <http://www.youtube.com/watch?v=efv0SQNde5Q>
+      Functional lenses for Scala by Edward Kmett on YouTube
+    @see <http://patternsinfp.wordpress.com/2011/01/31/lenses-are-the-coalgebras-for-the-costate-comonad/>
+      Lenses are the coalgebras for the costate comonad by Jeremy Gibbons *)
 
 type ('a, 'b) t = {
   get : 'a -> 'b;  (** Functional getter *)
@@ -29,8 +34,9 @@ val pair : ('a, 'b) t -> ('c, 'd) t -> ('a * 'c, 'b * 'd) t
 
 val cond : ('a -> bool) -> ('a, 'b) t -> ('a, 'b) t -> ('a, 'b) t
 (** Selects a lens checking a predicate.
-  
-  [cond pred lensTrue lensFalse]: [pred] is applied to source. If [true], [lensTrue] is selected. If [false], [lensFalse] is selected. *)
+
+    [cond pred lensTrue lensFalse]: [pred] is applied to source. If [true],
+    [lensTrue] is selected. If [false], [lensFalse] is selected. *)
 
 (** {3 State monad integration} *)
 
@@ -113,7 +119,6 @@ module Infix : sig
   (** {3 Pseudo-imperatives} *)
 
   val ( += ) : ('a, int) t -> int -> 'a -> 'a
-
   val ( -= ) : ('a, int) t -> int -> 'a -> 'a
 end
 
@@ -125,8 +130,6 @@ module StateInfix : sig
   (** {3 Pseudo-imperatives} *)
 
   val ( +=! ) : ('a, int) t -> int -> 'a -> unit * 'a
-
   val ( -=! ) : ('a, int) t -> int -> 'a -> unit * 'a
-
   val ( @=! ) : ('a, 'b list) t -> 'b list -> 'a -> unit * 'a
 end
