@@ -34,17 +34,6 @@ let test_parse_tasks_rest_service () =
   assert_equal ~printer:TestHelper.string_of_json_data_model tree tree';
   assert_equal ~printer:Yojson.Safe.to_string tasks_service_json json
 
-let test_parse_plus_rest_service () =
-  let plus_service_json =
-    Yojson.Safe.from_file "test_data/test_plus_rest_service.json"
-  in
-  let tree = GapiJson.json_to_data_model plus_service_json in
-  let plus_service = RestDescription.of_data_model tree in
-  let tree' = RestDescription.to_data_model plus_service in
-  let json = GapiJson.data_model_to_json tree' in
-  assert_equal ~printer:TestHelper.string_of_json_data_model tree tree';
-  assert_equal ~printer:Yojson.Safe.to_string plus_service_json json
-
 let test_parse_calendar_rest_service () =
   let calendar_service_json =
     Yojson.Safe.from_file "test_data/test_calendar_rest_service.json"
@@ -63,6 +52,5 @@ let suite =
          "test_parse_discovery_rest_service"
          >:: test_parse_discovery_rest_service;
          "test_parse_tasks_rest_service" >:: test_parse_tasks_rest_service;
-         "test_parse_plus_rest_service" >:: test_parse_plus_rest_service;
          "test_parse_calendar_rest_service" >:: test_parse_calendar_rest_service;
        ]
